==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/NetworkInterfaceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.NICType
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.PowerOnBootOption
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Network Interface model
 * @property deviceKey Gets or sets the device key value.
 * @property ipSettings Gets or sets the ipsettings.
 * @property name Gets or sets the name of the network interface.
 * @property networkId Gets or sets the ARM Id of the network resource to connect the virtual machine.
 * @property nicType NIC type
 * @property powerOnBoot Gets or sets the power on boot.
 */
public data class NetworkInterfaceArgs(
    public val deviceKey: Output<Int>? = null,
    public val ipSettings: Output<NicIPSettingsArgs>? = null,
    public val name: Output<String>? = null,
    public val networkId: Output<String>? = null,
    public val nicType: Output<Either<String, NICType>>? = null,
    public val powerOnBoot: Output<Either<String, PowerOnBootOption>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs.builder()
            .deviceKey(deviceKey?.applyValue({ args0 -> args0 }))
            .ipSettings(ipSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .networkId(networkId?.applyValue({ args0 -> args0 }))
            .nicType(
                nicType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .powerOnBoot(
                powerOnBoot?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [NetworkInterfaceArgs].
 */
@PulumiTagMarker
public class NetworkInterfaceArgsBuilder internal constructor() {
    private var deviceKey: Output<Int>? = null

    private var ipSettings: Output<NicIPSettingsArgs>? = null

    private var name: Output<String>? = null

    private var networkId: Output<String>? = null

    private var nicType: Output<Either<String, NICType>>? = null

    private var powerOnBoot: Output<Either<String, PowerOnBootOption>>? = null

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("jkpxhxdwfgkdijcq")
    public suspend fun deviceKey(`value`: Output<Int>) {
        this.deviceKey = value
    }

    /**
     * @param value Gets or sets the ipsettings.
     */
    @JvmName("elvutithjerquhgd")
    public suspend fun ipSettings(`value`: Output<NicIPSettingsArgs>) {
        this.ipSettings = value
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("ksdqvvhhaubbsnry")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the ARM Id of the network resource to connect the virtual machine.
     */
    @JvmName("llsdysbygnajatkw")
    public suspend fun networkId(`value`: Output<String>) {
        this.networkId = value
    }

    /**
     * @param value NIC type
     */
    @JvmName("dccyhucppwsnbaui")
    public suspend fun nicType(`value`: Output<Either<String, NICType>>) {
        this.nicType = value
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("kofudfihfyrfvrol")
    public suspend fun powerOnBoot(`value`: Output<Either<String, PowerOnBootOption>>) {
        this.powerOnBoot = value
    }

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("jbocvuerjucsttxu")
    public suspend fun deviceKey(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceKey = mapped
    }

    /**
     * @param value Gets or sets the ipsettings.
     */
    @JvmName("japbdytueuhekbxy")
    public suspend fun ipSettings(`value`: NicIPSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipSettings = mapped
    }

    /**
     * @param argument Gets or sets the ipsettings.
     */
    @JvmName("uhmjkbwfglfjkrfp")
    public suspend fun ipSettings(argument: suspend NicIPSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NicIPSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.ipSettings = mapped
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("cqbanoxavcbghvft")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the network resource to connect the virtual machine.
     */
    @JvmName("xlqvhrwucnhvyfvc")
    public suspend fun networkId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkId = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("usryqcaeacgiyuuj")
    public suspend fun nicType(`value`: Either<String, NICType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("ounhnwrfopqxelmp")
    public fun nicType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NICType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("rmlxfilawkahdyqt")
    public fun nicType(`value`: NICType) {
        val toBeMapped = Either.ofRight<String, NICType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("uosotmoeunawrvec")
    public suspend fun powerOnBoot(`value`: Either<String, PowerOnBootOption>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("sftivaeddtieqnky")
    public fun powerOnBoot(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PowerOnBootOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("odlsibkbpxjpvinu")
    public fun powerOnBoot(`value`: PowerOnBootOption) {
        val toBeMapped = Either.ofRight<String, PowerOnBootOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    internal fun build(): NetworkInterfaceArgs = NetworkInterfaceArgs(
        deviceKey = deviceKey,
        ipSettings = ipSettings,
        name = name,
        networkId = networkId,
        nicType = nicType,
        powerOnBoot = powerOnBoot,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/NetworkInterfaceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.NICType
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.PowerOnBootOption
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Network Interface model
 * @property deviceKey Gets or sets the device key value.
 * @property ipSettings Gets or sets the ipsettings.
 * @property name Gets or sets the name of the network interface.
 * @property networkId Gets or sets the ARM Id of the network resource to connect the virtual machine.
 * @property nicType NIC type
 * @property powerOnBoot Gets or sets the power on boot.
 */
public data class NetworkInterfaceArgs(
    public val deviceKey: Output<Int>? = null,
    public val ipSettings: Output<NicIPSettingsArgs>? = null,
    public val name: Output<String>? = null,
    public val networkId: Output<String>? = null,
    public val nicType: Output<Either<String, NICType>>? = null,
    public val powerOnBoot: Output<Either<String, PowerOnBootOption>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.NetworkInterfaceArgs.builder()
            .deviceKey(deviceKey?.applyValue({ args0 -> args0 }))
            .ipSettings(ipSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .networkId(networkId?.applyValue({ args0 -> args0 }))
            .nicType(
                nicType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .powerOnBoot(
                powerOnBoot?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [NetworkInterfaceArgs].
 */
@PulumiTagMarker
public class NetworkInterfaceArgsBuilder internal constructor() {
    private var deviceKey: Output<Int>? = null

    private var ipSettings: Output<NicIPSettingsArgs>? = null

    private var name: Output<String>? = null

    private var networkId: Output<String>? = null

    private var nicType: Output<Either<String, NICType>>? = null

    private var powerOnBoot: Output<Either<String, PowerOnBootOption>>? = null

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("vgbmnrdrgyhtunul")
    public suspend fun deviceKey(`value`: Output<Int>) {
        this.deviceKey = value
    }

    /**
     * @param value Gets or sets the ipsettings.
     */
    @JvmName("sefsiyiiaexoojpr")
    public suspend fun ipSettings(`value`: Output<NicIPSettingsArgs>) {
        this.ipSettings = value
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("jbouyftrnhuxnuwt")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the ARM Id of the network resource to connect the virtual machine.
     */
    @JvmName("kwdewsbbtotmpvpb")
    public suspend fun networkId(`value`: Output<String>) {
        this.networkId = value
    }

    /**
     * @param value NIC type
     */
    @JvmName("lsgenvjrvfsacwdi")
    public suspend fun nicType(`value`: Output<Either<String, NICType>>) {
        this.nicType = value
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("avypefgtnafexjfw")
    public suspend fun powerOnBoot(`value`: Output<Either<String, PowerOnBootOption>>) {
        this.powerOnBoot = value
    }

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("pnycdqishmkcypjy")
    public suspend fun deviceKey(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceKey = mapped
    }

    /**
     * @param value Gets or sets the ipsettings.
     */
    @JvmName("ndixiibdllsyjsam")
    public suspend fun ipSettings(`value`: NicIPSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipSettings = mapped
    }

    /**
     * @param argument Gets or sets the ipsettings.
     */
    @JvmName("kmrypmcrtwkbonvs")
    public suspend fun ipSettings(argument: suspend NicIPSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NicIPSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.ipSettings = mapped
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("qpfkieydplhysoud")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the network resource to connect the virtual machine.
     */
    @JvmName("yydgheknsmngnhfw")
    public suspend fun networkId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkId = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("guwisvlyivvgxvoa")
    public suspend fun nicType(`value`: Either<String, NICType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("lamlocnuirlxrogr")
    public fun nicType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NICType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("tplpluofkcvalqwb")
    public fun nicType(`value`: NICType) {
        val toBeMapped = Either.ofRight<String, NICType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("bfifcxpqerpaaaix")
    public suspend fun powerOnBoot(`value`: Either<String, PowerOnBootOption>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("thqygvrldaahvclr")
    public fun powerOnBoot(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PowerOnBootOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    /**
     * @param value Gets or sets the power on boot.
     */
    @JvmName("yqnapfcxfekaxqge")
    public fun powerOnBoot(`value`: PowerOnBootOption) {
        val toBeMapped = Either.ofRight<String, PowerOnBootOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    internal fun build(): NetworkInterfaceArgs = NetworkInterfaceArgs(
        deviceKey = deviceKey,
        ipSettings = ipSettings,
        name = name,
        networkId = networkId,
        nicType = nicType,
        powerOnBoot = powerOnBoot,
    )
}
